<!--
  ~ Copyright (c) 2023-2024 Datalayer, Inc.
  ~
  ~ Datalayer License
-->

---
sidebar_position: 1
---

# About

This is the documentation web site for Jupyter Kernels, a solution to scale your JupyterLab in the cloud with Remote Kernels and Local Files.

